@@ -38,16 +38,16 @@ setMethod(
   "checkObject",
   signature(sim = "simList", name = "missing", object = "Raster", layer = "character"),
   definition = function(sim, object, layer, ...) {
-    if (exists(deparse(substitute(object)), envir = sim@.envir)) {
+    if (exists(deparse(substitute(object)), envir = sim@.xData)) {
       if (!is.na(match(layer, names(object)))) {
         return(invisible(TRUE))
       } else {
-        message(paste(deparse(substitute(object, env = sim@.envir)),
+        message(paste(deparse(substitute(object, env = sim@.xData)),
                       "exists, but", layer, "is not a layer"))
         return(FALSE)
       }
     } else {
-      message(paste(deparse(substitute(object, env = sim@.envir)),
+      message(paste(deparse(substitute(object, env = sim@.xData)),
                     "does not exist."))
       return(FALSE)
     }
@@ -59,10 +59,10 @@ setMethod(
   "checkObject",
   signature(sim = "simList", name = "missing", object = "ANY", layer = "missing"),
   definition = function(sim, name, object, ...) {
-    if (exists(deparse(substitute(object)), envir = sim@.envir)) {
+    if (exists(deparse(substitute(object)), envir = sim@.xData)) {
       return(invisible(TRUE))
     } else {
-      message(paste(deparse(substitute(object, env = sim@.envir)),
+      message(paste(deparse(substitute(object, env = sim@.xData)),
                     "does not exist"))
       return(FALSE)
     }
@@ -74,7 +74,7 @@ setMethod(
   "checkObject",
   signature(sim = "simList", name = "character", object = "missing", layer = "missing"),
   definition = function(sim, name, ...) {
-    if (exists(name, envir = sim@.envir)) {
+    if (exists(name, envir = sim@.xData)) {
       return(invisible(TRUE))
     } else {
       simName <- .objectNames("spades", "simList", "sim")[[1]]$objs
@@ -89,7 +89,7 @@ setMethod(
   "checkObject",
   signature(sim = "simList", name = "character", object = "missing", layer = "character"),
   definition = function(sim, name, layer, ...) {
-    if (exists(name, envir = sim@.envir)) {
+    if (exists(name, envir = sim@.xData)) {
       if (is(sim[[name]], "Raster")) {
         if (!is(sim[[name]][[layer]], "Raster")) {
           message(paste("The object \"", name, "\" exists, but is not
@@ -163,11 +163,11 @@ setMethod(
       readFile <- list()
       for (uM in userModules) {
         filename <- paste(path, "/", uM, "/", uM, ".R", sep = "")
-        readFile[[uM]] <- if (!is.null(sim@.envir[[".parsedFiles"]][[filename]])) {
+        readFile[[uM]] <- if (!is.null(sim@.xData[[".parsedFiles"]][[filename]])) {
           # a little faster to use already parsed objects --
           #   might have happened earlier during simInit,
           #   if this checkParams was run from simInit
-          tmp <- .parseConditional(envir = sim@.envir[[".parsedFiles"]],
+          tmp <- .parseConditional(envir = sim@.xData[[".parsedFiles"]],
                                   filename = filename)
           deparse(tmp$parsedFile)
         } else {
