@@ -39,7 +39,7 @@ setMethod(
   "depsEdgeList",
   signature(sim = "simList", plot = "logical"),
   definition = function(sim, plot) {
-    deps <- depends(sim)
+    deps <- sim@depends
     DT <- .depsEdgeListMem(deps, plot)
     return(DT)
 })
@@ -86,7 +86,6 @@ setMethod("depsEdgeList",
                      objName = character(0), objClass = character(0))
   }
   setorder(DT, "from", "to", "objName")
-
 }
 
 .depsEdgeListMem <- memoise::memoise(.depsEdgeList)
@@ -176,7 +175,7 @@ setMethod(
             pth1 <- data.frame(from = rownames(M)[pth1],
                                to = rownames(M)[lead(match(names(pth1), rownames(M)), 1)],
                                stringsAsFactors = FALSE) %>%
-                    na.omit %>% as.data.table()
+                    na.omit() %>% as.data.table()
 
             pth2 <- shortest_paths(simGraph,
                                    from = colnames(M)[col],
@@ -184,7 +183,7 @@ setMethod(
             pth2 <- data.frame(from = rownames(M)[pth2],
                                to = rownames(M)[lead(match(names(pth2), rownames(M)), 1)],
                                stringsAsFactors = FALSE) %>%
-                    na.omit %>% as.data.table()
+                    na.omit() %>% as.data.table()
 
             pth <- rbindlist(list(pth, rbindlist(list(pth1, pth2))))
           }
